==> spring-cloud-contract-shade-4.1.3-sources.jar: shaded/org/apache/maven/artifact/repository/layout/ArtifactRepositoryLayout.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package shaded.shaded.org.apache.maven.artifact.repository.layout;

import shaded.shaded.org.apache.maven.artifact.Artifact;
import shaded.shaded.org.apache.maven.artifact.metadata.ArtifactMetadata;
import shaded.shaded.org.apache.maven.artifact.repository.ArtifactRepository;

/**
 * Repository layout.
 *
 * @author jdcasey
 * @deprecated Avoid use of this type, if you need access to local repository use repository system session instead.
 */
@Deprecated
public interface ArtifactRepositoryLayout {
    String ROLE = ArtifactRepositoryLayout.class.getName();

    String getId();

    String pathOf(Artifact artifact);

    String pathOfLocalRepositoryMetadata(ArtifactMetadata metadata, ArtifactRepository repository);

    String pathOfRemoteRepositoryMetadata(ArtifactMetadata metadata);
}

==> spring-cloud-contract-shade-4.2.2-sources.jar: shaded/org/apache/maven/artifact/repository/layout/ArtifactRepositoryLayout.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package shaded.org.apache.maven.artifact.repository.layout;

import shaded.org.apache.maven.artifact.Artifact;
import shaded.org.apache.maven.artifact.metadata.ArtifactMetadata;
import shaded.org.apache.maven.artifact.repository.ArtifactRepository;

/**
 * Repository layout.
 *
 * @author jdcasey
 * @deprecated Avoid use of this type, if you need access to local repository use repository system session instead.
 */
@Deprecated
public interface ArtifactRepositoryLayout {
    String ROLE = ArtifactRepositoryLayout.class.getName();

    String getId();

    String pathOf(Artifact artifact);

    String pathOfLocalRepositoryMetadata(ArtifactMetadata metadata, ArtifactRepository repository);

    String pathOfRemoteRepositoryMetadata(ArtifactMetadata metadata);
}
